@@ -7,7 +7,7 @@ use std::error::Error;
 use std::ffi::CString;
 use std::ops::Drop;
 
-const WLUMA_VERSION: u32 = vk::make_api_version(0, 4, 3, 0);
+const WLUMA_VERSION: u32 = vk::make_api_version(0, 4, 4, 0);
 const VULKAN_VERSION: u32 = vk::make_api_version(0, 1, 2, 0);
 
 const FINAL_MIP_LEVEL: u32 = 4; // Don't generate mipmaps beyond this level - GPU is doing too poor of a job averaging the colors
@@ -54,7 +54,7 @@ impl Vulkan {
 
         let physical_devices = unsafe { instance.enumerate_physical_devices()? };
         let physical_device = *physical_devices
-            .get(0)
+            .first()
             .ok_or("Unable to find a physical device")?;
 
         let queue_family_index = 0;
